from argparse import ArgumentParser
from dodo_commands.framework import Dodo
from six.moves import configparser
import os


def _args():
    parser = ArgumentParser(
        description="Write a value of the global Dodo Command configuration"
    )
    parser.add_argument('key')
    parser.add_argument('val', nargs='?')
    args = Dodo.parse_args(parser)
    return args


def _config_filename():
    return os.path.expanduser("~/.dodo_commands/config")


def _write_config(config):
    """Save configuration."""
    with open(_config_filename(), "w") as f:
        config.write(f)


def _read_config():
    """Save configuration."""
    config = configparser.ConfigParser()
    config.read(_config_filename())
    return config


if Dodo.is_main(__name__, safe=False):
    args = _args()
    config = _read_config()
    section, key = args.key.split('.')
    if args.val:
        config.set(section, key, args.val)
        _write_config(config)
    else:
        print(config.get(section, key))



from argparse import ArgumentParser
from dodo_commands.framework import Dodo
from dodo_commands.framework.config import (
    CommandPath, get_project_dir, get_global_config
)
import os
import sys


def _args():  # noqa
    parser = ArgumentParser(
        description=(
            'Print the value of /ROOT/<what>_dir. For example: ' +
            '"dodo which src" prints the value of /ROOT/src_dir.')
    )
    parser.add_argument(
        'what',
        nargs='?',
    )

    group = parser.add_mutually_exclusive_group()
    group.add_argument(
        '--config',
        action="store_true",
        help='Print where the config file is')
    group.add_argument(
        '--global-config',
        action="store_true",
        help='Print where the global config file is')
    group.add_argument(
        '--script',
        help='Print where the dodo command script with given name is')
    group.add_argument(
        '--dir',
        dest='directory',
        help='Finds the X_dir value in the configuration, where X is the given option value')
    group.add_argument(
        '--decorators',
        action="store_true",
        help='Prints which command decorators are available')
    group.add_argument(
        '--projects',
        action="store_true",
        help='Prints which projects are available')
    group.add_argument(
        '--default-commands',
        action="store_true",
        help='Prints the directory where default commands are stored')

    return Dodo.parse_args(parser)


def _which_script(script):
    command_path = CommandPath(Dodo.config)
    for item in command_path.items:
        script_path = os.path.join(
            item.full_path, script + ".py"
        )
        if os.path.exists(script_path):
            return script_path
    return None


def _which_dir(directory):
    return Dodo.get_config("/ROOT/%s_dir" % directory, None)


def _projects_dir():
    return os.path.expanduser(
        get_global_config().get("settings", "projects_dir")
    )


if Dodo.is_main(__name__):
    args = _args()

    if args.config:
        print(
            os.path.join(
                get_project_dir(), "dodo_commands", "res", "config.yaml"
            )
        )
    elif args.global_config:
        sys.stdout.write(os.path.expanduser('~/.dodo_commands/config\n'))
    elif args.default_commands:
        sys.stdout.write(os.path.expanduser('~/.dodo_commands/default_commands\n'))
    elif args.script:
        sys.stdout.write(_which_script(args.script) + "\n")
    elif args.directory:
        sys.stdout.write(_which_dir(args.directory) + "\n")
    elif args.decorators:
        sys.stdout.write(", ".join(sorted(Dodo.all_decorators().keys())) + "\n")
    elif args.projects:
        projects = [
            x for x in os.listdir(_projects_dir())
            if os.path.isdir(os.path.join(_projects_dir(), x, "dodo_commands", "res"))
        ]
        sys.stdout.write("\n".join(sorted(projects)) + "\n")
    elif args.what:
        x = _which_script(args.what) or _which_dir(args.what)
        if x:
            sys.stdout.write(x + "\n")
    else:
        sys.stdout.write(Dodo.get_config("/ROOT/project_name") + "\n")



from argparse import ArgumentParser
from dodo_commands.framework import Dodo, CommandError
from dodo_commands.dodo_activate import Activator


def _args():
    parser = ArgumentParser()
    parser.add_argument('project', nargs='?')

    group = parser.add_mutually_exclusive_group()
    group.add_argument('--latest', action="store_true")
    group.add_argument('--create', action="store_true")
    args = Dodo.parse_args(parser)
    return args


if Dodo.is_main(__name__, safe=False):
    args = _args()
    if not args.project and not args.latest:
        raise CommandError("No project was specified")
    Activator().run(args.project, args.latest, args.create)



from argparse import ArgumentParser
from dodo_commands.framework import Dodo
from plumbum.cmd import docker
from six.moves import input as raw_input
import sys


def _args():
    parser = ArgumentParser()
    args = Dodo.parse_args(parser)
    return args


def _containers():
    result = []
    for line in docker("ps", "--format", "{{.ID}} {{.Names}} {{.Image}}").split('\n'):
        if line:
            cid, name, image = line.split()
            result.append(dict(name=name, cid=cid, image=image))
    return result


if Dodo.is_main(__name__):
    args = _args()
    while True:
        containers = _containers()

        print("0 - exit")
        for idx, container in enumerate(containers):
            print("%d - %s" % (idx + 1, container['name']))
        print("999 - all of the above")

        print("\nSelect a container: ")
        raw_choice = int(raw_input())
        kill_all = raw_choice == 999
        choice = raw_choice - 1

        if choice == -1:
            sys.exit(0)
        elif kill_all:
            pass
        else:
            containers = [containers[choice]]
        for container in containers:
            Dodo.runcmd(
                ['docker', 'kill', container['cid']],
            )
        if kill_all:
            sys.exit(0)
